@@ -26,7 +26,6 @@
  * this work is sponsored by Appian Graphics.
  * 
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/glint/pm3_dac.c,v 1.33tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -115,8 +114,9 @@ Permedia3MemorySizeDetect(ScrnInfoPtr pScrn)
 	for(i=0;i<32;i++) {
 	    /* Clear first 32MB */
 	    MMIO_OUT32(pGlint->FbBase, i*1024*1024, 0);
-	    mem_barrier();
 	}
+	mem_barrier();
+
         for(i=32;i<64;i++) {
     	    /* write test pattern */
 	    MMIO_OUT32(pGlint->FbBase, i*1024*1024, i*0x00345678);
@@ -437,15 +437,14 @@ Permedia3PreInit(ScrnInfoPtr pScrn)
 		       "VX1 secondary enabling VGA before int10\n");
 
 	    /* Enable VGA on the current card. */
-	    pciWriteByte( pGlint->PciTag, 0xf8, 0 );
-	    pciWriteByte( pGlint->PciTag, 0xf4, 0 );
-	    pciWriteByte( pGlint->PciTag, 0xfc, 0 );
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0, 0xf8);
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0, 0xf4);
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0, 0xfc);
 
 	    /* The card we are on should be VGA-enabled now, so run int10. */
 	    if (xf86LoadSubModule(pScrn, "int10")) {
 	        xf86Int10InfoPtr pInt;
 
-	        xf86LoaderReqSymLists(GLINTint10Symbols, NULL);
 		xf86DrvMsg(pScrn->scrnIndex, X_INFO, "Initializing int10\n");
 		pInt = xf86InitInt10(pGlint->pEnt->index);
 		xf86FreeInt10(pInt);
@@ -455,9 +454,9 @@ Permedia3PreInit(ScrnInfoPtr pScrn)
 		       "VX1 secondary disabling VGA after int10\n");
 
 	    /* Finally, disable VGA on the current card. */
-	    pciWriteByte( pGlint->PciTag, 0xf8, 0x70 );
-	    pciWriteByte( pGlint->PciTag, 0xf4, 0x01 );
-	    pciWriteByte( pGlint->PciTag, 0xfc, 0x00 );
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0x70, 0xf8);
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0x01, 0xf4);
+	    PCI_WRITE_BYTE(pGlint->PciInfo, 0x00, 0xfc);
 	}
     }
 #endif /* __alpha__ */
@@ -502,7 +501,7 @@ Permedia3Init(ScrnInfoPtr pScrn, DisplayModePtr mode, GLINTRegPtr pReg)
     temp3 = mode->CrtcHSyncEnd - mode->CrtcHSyncStart;
     temp4 = mode->CrtcVSyncEnd - mode->CrtcVSyncStart;
 
-    STOREREG(PMHTotal,	Shiftbpp(pScrn, mode->CrtcHTotal - 1));
+    STOREREG(PMHTotal,	Shiftbpp(pScrn, mode->CrtcHTotal) - 1);
     STOREREG(PMHsEnd,	Shiftbpp(pScrn, temp1 + temp3));
     STOREREG(PMHsStart,	Shiftbpp(pScrn, temp1));
     STOREREG(PMHbEnd,	Shiftbpp(pScrn, mode->CrtcHTotal - mode->CrtcHDisplay));
