@@ -28,7 +28,6 @@
  * 
  * GLINT 500TX / MX accelerated options.
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/glint/tx_accel.c,v 1.27 2001/05/29 11:23:38 alanh Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -254,9 +253,7 @@ TXAccelInit(ScreenPtr pScreen)
 					       BIT_ORDER_IN_BYTE_LSBFIRST;
 
     infoPtr->NumScanlineColorExpandBuffers = 1;
-    pGlint->ScratchBuffer                 = xalloc(((pScrn->virtualX+62)/32*4)
-					    + (pScrn->virtualX
-					    * pScrn->bitsPerPixel / 8));
+    pGlint->ScratchBuffer                 = malloc(((pScrn->virtualX + 62) / 32 * 4) + (pScrn->virtualX * pScrn->bitsPerPixel / 8));
     infoPtr->ScanlineColorExpandBuffers = 
 					pGlint->XAAScanlineColorExpandBuffers;
     pGlint->XAAScanlineColorExpandBuffers[0] = 
@@ -296,7 +293,6 @@ static void TXLoadCoord(
 ){
     GLINTPtr pGlint = GLINTPTR(pScrn);
     
-#ifndef XF86DRI
     if (w != pGlint->startxsub) {
     	GLINT_WRITE_REG(w<<16, StartXSub);
 	pGlint->startxsub = w;
@@ -321,20 +317,6 @@ static void TXLoadCoord(
     	GLINT_WRITE_REG(d<<16,dY);
 	pGlint->dy = d;
     }
-#else
-    	GLINT_WRITE_REG(w<<16, StartXSub);
-    	GLINT_WRITE_REG(x<<16,StartXDom);
-    	GLINT_WRITE_REG(y<<16,StartY);
-    	GLINT_WRITE_REG(h,GLINTCount);
-    	GLINT_WRITE_REG(a<<16,dXDom);
-    	GLINT_WRITE_REG(d<<16,dY);
-	pGlint->startxsub = w;
-	pGlint->startxdom = x;
-	pGlint->starty = y;
-	pGlint->count = h;
-	pGlint->dxdom = a;
-	pGlint->dy = d;
-#endif
 }
 
 static void
